@@ -1,6 +1,6 @@
-from utils.toolkit import gradient_check, SummaryProfile
-from nn.rng import manual_seed_all, randn, tensor, zeros, ones, rand, randint
-import nn
+from xs.utils.toolkit import gradient_check, SummaryProfile
+from xs.nn.rng import manual_seed_all, randn, tensor, zeros, ones, rand, randint
+import xs.nn
 
 
 # dtype
