@@ -1,5 +1,5 @@
 from .grad_fn import *
-from core import __global as GLOBAL
+from xs.core import __global as GLOBAL
 
 
 # math opearations
@@ -9,7 +9,7 @@ def add(lhs: Tensor, rhs: Tensor, out: Tensor = None) -> Tensor:
     if out is None:
         out = Tensor(GLOBAL.np.empty_like(lhs.eval))
     out.requires_grad = lhs.requires_grad or rhs.requires_grad
-    nn.td_functional.add(lhs.eval, rhs.eval, out.eval)
+    xs.nn.td_functional.add(lhs.eval, rhs.eval, out.eval)
     if out.is_dynamic:
         lhs.add_out_bounds(out)
         rhs.add_out_bounds(out)
@@ -27,7 +27,7 @@ def sub(lhs: Tensor, rhs: Tensor, out: Tensor = None) -> Tensor:
     if out is None:
         out = Tensor(GLOBAL.np.empty_like(lhs.eval))
     out.requires_grad = lhs.requires_grad or rhs.requires_grad
-    nn.td_functional.sub(lhs.eval, rhs.eval, out.eval)
+    xs.nn.td_functional.sub(lhs.eval, rhs.eval, out.eval)
     if out.is_dynamic:
         lhs.add_out_bounds(out)
         rhs.add_out_bounds(out)
@@ -45,7 +45,7 @@ def mul(lhs: Tensor, rhs: Tensor, out: Tensor = None) -> Tensor:
     if out is None:
         out = Tensor(GLOBAL.np.empty_like(lhs.eval))
     out.requires_grad = lhs.requires_grad or rhs.requires_grad
-    nn.td_functional.mul(lhs.eval, rhs.eval, out.eval)
+    xs.nn.td_functional.mul(lhs.eval, rhs.eval, out.eval)
 
     if out.is_dynamic:
         lhs.add_out_bounds(out)
@@ -84,7 +84,7 @@ def mm(lhs: Tensor, rhs: Tensor, out: Tensor = None) -> Tensor:
     if out is None:
         out = Tensor(GLOBAL.np.empty((lhs.shape[0], rhs.shape[-1])))
     out.requires_grad = lhs.requires_grad or rhs.requires_grad
-    nn.td_functional.mm(lhs.eval, rhs.eval, out.eval)
+    xs.nn.td_functional.mm(lhs.eval, rhs.eval, out.eval)
 
     if out.is_dynamic:
         out.add_in_bounds(lhs, rhs)
@@ -102,11 +102,11 @@ def addmm(b: Tensor, x1: Tensor, x2: Tensor, out: Tensor = None) -> Tensor:
     requires_grad = x1.requires_grad or x2.requires_grad or b.requires_grad
     if out is not None:
         assert isinstance(out, Tensor)
-        nn.td_functional.mm(x1.eval, x2.eval, out.eval)
-        nn.td_functional.add(out.eval, b.eval, out.eval)
+        xs.nn.td_functional.mm(x1.eval, x2.eval, out.eval)
+        xs.nn.td_functional.add(out.eval, b.eval, out.eval)
     else:
-        out_data = nn.td_functional.mm(x1.eval, x2.eval)
-        nn.td_functional.add(out_data, b.eval, out_data)
+        out_data = xs.nn.td_functional.mm(x1.eval, x2.eval)
+        xs.nn.td_functional.add(out_data, b.eval, out_data)
         out = Tensor(data=out_data)
     out.requires_grad = requires_grad
     if out.is_dynamic:
@@ -126,7 +126,7 @@ def truediv(lhs: Tensor, rhs: Tensor, out: Tensor = None) -> Tensor:
     if out is None:
         out = Tensor(GLOBAL.np.empty_like(lhs.eval))
     out.requires_grad = lhs.requires_grad or rhs.requires_grad
-    nn.td_functional.div(lhs.eval, rhs.eval, out.eval)
+    xs.nn.td_functional.div(lhs.eval, rhs.eval, out.eval)
 
     if out.is_dynamic:
         lhs.add_out_bounds(out)
@@ -145,7 +145,7 @@ def floordiv(lhs: Tensor, rhs: Tensor, out: Tensor = None) -> Tensor:
     if out is None:
         out = Tensor(GLOBAL.np.empty_like(lhs.eval))
     out.requires_grad = lhs.requires_grad or rhs.requires_grad
-    nn.td_functional.floor_div(lhs.eval, rhs.eval, out.eval)
+    xs.nn.td_functional.floor_div(lhs.eval, rhs.eval, out.eval)
 
     if out.is_dynamic:
         lhs.add_out_bounds(out)
@@ -163,9 +163,9 @@ def max(x: Tensor, axis: int = None, keepdims: bool = False, out: Tensor = None)
         GLOBAL.INPUTS = x
     if out is not None:
         assert isinstance(out, Tensor)
-        nn.td_functional.max(x.eval, axis, keepdims, out.eval)
+        xs.nn.td_functional.max(x.eval, axis, keepdims, out.eval)
     else:
-        out = Tensor(nn.td_functional.max(x.eval, axis, keepdims))
+        out = Tensor(xs.nn.td_functional.max(x.eval, axis, keepdims))
 
     if out.is_dynamic:
         out.add_in_bounds(x)
@@ -185,10 +185,10 @@ def maximum(x1: Union[int, float, ndarray, Tensor], x2: Union[int, float, GLOBAL
         if out is None:
             out = Tensor(GLOBAL.np.empty_like(x1.eval))
         if isinstance(x2, (int, float, ndarray)):
-            nn.td_functional.maximum(x1.eval, x2, out.eval)
+            xs.nn.td_functional.maximum(x1.eval, x2, out.eval)
             out.requires_grad = x1.requires_grad
         elif isinstance(x2, Tensor):
-            nn.td_functional.maximum(x1.eval, x2.eval, out.eval)
+            xs.nn.td_functional.maximum(x1.eval, x2.eval, out.eval)
             out.requires_grad = x1.requires_grad or x2.requires_grad
         else:
             raise TypeError('unknown type for {}'.format(type(x2)))
@@ -196,10 +196,10 @@ def maximum(x1: Union[int, float, ndarray, Tensor], x2: Union[int, float, GLOBAL
         if out is None:
             out = Tensor(GLOBAL.np.empty_like(x2.eval))
         if isinstance(x1, (int, float, GLOBAL.np.ndarray)):
-            nn.td_functional.maximum(x1, x2.eval, out.eval)
+            xs.nn.td_functional.maximum(x1, x2.eval, out.eval)
             out.requires_grad = x2.requires_grad
         elif isinstance(x1, Tensor):
-            nn.td_functional.maximum(x1.eval, x2.eval, out.eval)
+            xs.nn.td_functional.maximum(x1.eval, x2.eval, out.eval)
             out.requires_grad = x1.requires_grad or x2.requires_grad
         else:
             raise TypeError('unknown type for {}'.format(type(x1)))
@@ -226,9 +226,9 @@ def sum(x: Tensor, axis: int = None, keepdims: bool = False, out: Tensor = None)
         GLOBAL.INPUTS = x
     if out is not None:
         assert isinstance(out, Tensor)
-        nn.td_functional.sum(x.eval, axis, keepdims, out.eval)
+        xs.nn.td_functional.sum(x.eval, axis, keepdims, out.eval)
     else:
-        out = Tensor(nn.td_functional.sum(x.eval, axis, keepdims))
+        out = Tensor(xs.nn.td_functional.sum(x.eval, axis, keepdims))
 
     if out.is_dynamic:
         out.add_in_bounds(x)
@@ -246,9 +246,9 @@ def mean(x: Tensor, axis: int = None, keepdims: bool = False, out: Tensor = None
         GLOBAL.INPUTS = x
     if out is not None:
         assert isinstance(out, Tensor)
-        nn.td_functional.mean(x.eval, axis, keepdims, out.eval)
+        xs.nn.td_functional.mean(x.eval, axis, keepdims, out.eval)
     else:
-        out = Tensor(nn.td_functional.mean(x.eval, axis, keepdims))
+        out = Tensor(xs.nn.td_functional.mean(x.eval, axis, keepdims))
     out.requires_grad = x.requires_grad
     if out.is_dynamic:
         out.add_in_bounds(x)
@@ -265,9 +265,9 @@ def norm(x: Tensor, p: int = 2, axis: int = None, keepdims: bool = False, out: T
         GLOBAL.INPUTS = x
     if out is not None:
         assert isinstance(out, Tensor)
-        nn.td_functional.norm(x.eval, p, axis, keepdims, out.eval)
+        xs.nn.td_functional.norm(x.eval, p, axis, keepdims, out.eval)
     else:
-        out = Tensor(nn.td_functional.norm(x.eval, p, axis, keepdims))
+        out = Tensor(xs.nn.td_functional.norm(x.eval, p, axis, keepdims))
     if out.is_dynamic:
         out.add_in_bounds(x)
         x.add_out_bounds(out)
@@ -298,11 +298,11 @@ def relu(inputs: Tensor, inplace: bool = False, out: Tensor = None) -> Tensor:
     if GLOBAL.INPUTS is None:
         GLOBAL.INPUTS = inputs
     if inplace:
-        nn.td_functional.relu(inputs.eval, inputs.eval)
+        xs.nn.td_functional.relu(inputs.eval, inputs.eval)
         return inputs
     if out is None:
         out = Tensor(data=GLOBAL.np.empty_like(inputs.eval))
-    nn.td_functional.relu(inputs.eval, out.eval)
+    xs.nn.td_functional.relu(inputs.eval, out.eval)
     out.requires_grad = inputs.requires_grad
     if out.is_dynamic:
         out.add_in_bounds(inputs)
@@ -318,7 +318,7 @@ def sigmoid(inputs: Tensor, out: Tensor = None) -> Tensor:
         GLOBAL.INPUTS = inputs
     if out is None:
         out = Tensor(data=GLOBAL.np.empty_like(inputs.eval))
-    nn.td_functional.sigmoid(inputs.eval, out.eval)
+    xs.nn.td_functional.sigmoid(inputs.eval, out.eval)
     if out.is_dynamic:
         out.add_in_bounds(inputs)
         inputs.add_out_bounds(out)
@@ -334,7 +334,7 @@ def tanh(inputs: Tensor, out: Tensor = None) -> Tensor:
         GLOBAL.INPUTS = inputs
     if out is None:
         out = Tensor(data=GLOBAL.np.empty_like(inputs.eval))
-    nn.td_functional.tanh(inputs.eval, out.eval)
+    xs.nn.td_functional.tanh(inputs.eval, out.eval)
     if out.is_dynamic:
         out.add_in_bounds(inputs)
         inputs.add_out_bounds(out)
@@ -351,7 +351,7 @@ def softmax(inputs: Tensor, out: Tensor = None) -> Tensor:
     if out is None:
         out = Tensor(data=GLOBAL.np.empty_like(inputs.eval))
     out.requires_grad = inputs.requires_grad
-    nn.td_functional.softmax(inputs.eval, out.eval)
+    xs.nn.td_functional.softmax(inputs.eval, out.eval)
     if 'softmax' in inputs.cache.keys():
         inputs.cache['softmax'] = out
     return out
@@ -363,7 +363,7 @@ def log_softmax(inputs: Tensor, out: Tensor = None) -> Tensor:
     if out is None:
         out = Tensor(data=GLOBAL.np.empty_like(inputs.eval))
     out.requires_grad = inputs.requires_grad
-    nn.td_functional.log_softmax(inputs.eval, out.eval)
+    xs.nn.td_functional.log_softmax(inputs.eval, out.eval)
     return out
 
 
@@ -371,9 +371,9 @@ def flatten(inputs: Tensor, start: int = 1, out: Tensor = None) -> Tensor:
     if GLOBAL.INPUTS is None:
         GLOBAL.INPUTS = inputs
     if out is None:
-        out = Tensor(data=nn.td_functional.flatten(inputs.eval, start))
+        out = Tensor(data=xs.nn.td_functional.flatten(inputs.eval, start))
     else:
-        out.eval = nn.td_functional.flatten(inputs.eval, start)
+        out.eval = xs.nn.td_functional.flatten(inputs.eval, start)
     out.requires_grad = inputs.requires_grad
     if out.is_dynamic:
         out.add_in_bounds(inputs)
@@ -693,8 +693,8 @@ def batch_norm(inputs: Tensor, gamma: Tensor, beta: Tensor, moving_mean: Tensor,
         sqrtvar = GLOBAL.np.sqrt(var + epsilon)
         normalized_x = GLOBAL.np.divide(xmu, sqrtvar)
 
-        GLOBAL.np.multiply(nn.td_functional.expand_as(gamma.eval, normalized_x), normalized_x, out=out.eval)
-        GLOBAL.np.add(out.eval, nn.td_functional.expand_as(beta.eval, out.eval), out=out.eval)
+        GLOBAL.np.multiply(xs.nn.td_functional.expand_as(gamma.eval, normalized_x), normalized_x, out=out.eval)
+        GLOBAL.np.add(out.eval, xs.nn.td_functional.expand_as(beta.eval, out.eval), out=out.eval)
 
         # update moving mean
         GLOBAL.np.multiply(momentum, moving_mean.eval, out=moving_mean.eval)
@@ -717,12 +717,12 @@ def batch_norm(inputs: Tensor, gamma: Tensor, beta: Tensor, moving_mean: Tensor,
         # GLOBAL.np.add(moving_variance_data, moving_mean_data, out=out.eval)
         moving_variance_data = GLOBAL.np.add(moving_variance.eval, epsilon)
         GLOBAL.np.sqrt(moving_variance_data, out=moving_variance_data)
-        moving_mean_data = GLOBAL.np.subtract(inputs.eval, nn.td_functional.expand_as(moving_mean.eval, inputs.eval))
-        GLOBAL.np.divide(moving_mean_data, nn.td_functional.expand_as(moving_variance_data, moving_mean_data), out=out.eval)
+        moving_mean_data = GLOBAL.np.subtract(inputs.eval, xs.nn.td_functional.expand_as(moving_mean.eval, inputs.eval))
+        GLOBAL.np.divide(moving_mean_data, xs.nn.td_functional.expand_as(moving_variance_data, moving_mean_data), out=out.eval)
         # GLOBAL.np.multiply(gamma.eval, out.eval, out=out.eval)
-        GLOBAL.np.multiply(nn.td_functional.expand_as(gamma.eval, out.eval), out.eval, out=out.eval)
+        GLOBAL.np.multiply(xs.nn.td_functional.expand_as(gamma.eval, out.eval), out.eval, out=out.eval)
         # GLOBAL.np.add(beta.eval, out.eval, out=out.eval)
-        GLOBAL.np.add(nn.td_functional.expand_as(beta.eval, out.eval), out.eval, out=out.eval)
+        GLOBAL.np.add(xs.nn.td_functional.expand_as(beta.eval, out.eval), out.eval, out=out.eval)
 
     out.requires_grad = inputs.requires_grad or gamma.requires_grad or beta.requires_grad
     if out.is_dynamic:
@@ -755,8 +755,8 @@ def layer_norm(inputs: Tensor, gamma: Tensor, beta: Tensor, epsilon: float = 1e-
     GLOBAL.np.sqrt(sqrtvar + epsilon, out=sqrtvar)
 
     normalized_x = GLOBAL.np.divide(xmu, sqrtvar)
-    GLOBAL.np.multiply(nn.td_functional.expand_as(gamma.eval, out.eval), normalized_x, out=out.eval)
-    GLOBAL.np.add(out.eval, nn.td_functional.expand_as(beta.eval, out.eval), out=out.eval)
+    GLOBAL.np.multiply(xs.nn.td_functional.expand_as(gamma.eval, out.eval), normalized_x, out=out.eval)
+    GLOBAL.np.add(out.eval, xs.nn.td_functional.expand_as(beta.eval, out.eval), out=out.eval)
     if out.is_dynamic:
         out.add_in_bounds(inputs, gamma, beta)
         inputs.add_out_bounds(out)
@@ -791,8 +791,8 @@ def group_norm(inputs: Tensor, gamma: Tensor, beta: Tensor,  epsilon: float = 1e
 
     x_group_norm = GLOBAL.np.divide(xgmu, sqrtvar)
     x_norm = GLOBAL.np.reshape(x_group_norm, (n, c, h, w))
-    GLOBAL.np.multiply(nn.td_functional.expand_as(gamma.eval, out.eval), x_norm, out=out.eval)
-    GLOBAL.np.add(out.eval, nn.td_functional.expand_as(beta.eval, out.eval), out=out.eval)
+    GLOBAL.np.multiply(xs.nn.td_functional.expand_as(gamma.eval, out.eval), x_norm, out=out.eval)
+    GLOBAL.np.add(out.eval, xs.nn.td_functional.expand_as(beta.eval, out.eval), out=out.eval)
 
     if out.is_dynamic:
         out.add_in_bounds(inputs, gamma, beta)
@@ -919,8 +919,8 @@ def bce_with_logits_loss(x1: Tensor, x2: Tensor, reduction: str = 'mean', out: T
         else:
             raise TypeError('unknown type for reduction')
 
-    pred = nn.td_functional.sigmoid(x1.eval)
-    nn.td_functional.bce_loss(pred, x2.eval, reduction, out.eval)
+    pred = xs.nn.td_functional.sigmoid(x1.eval)
+    xs.nn.td_functional.bce_loss(pred, x2.eval, reduction, out.eval)
     if out.is_dynamic:
         out.add_in_bounds(x1, x2)
         x1.add_out_bounds(out)
@@ -943,7 +943,7 @@ def bce_loss(x1: Tensor, x2: Tensor, reduction: str = 'mean', out: Tensor = None
             out = Tensor(GLOBAL.np.empty_like(x1.eval))
         else:
             raise TypeError('unknown type for reduction')
-    nn.td_functional.bce_loss(x1.eval, x2.eval, reduction, out.eval)
+    xs.nn.td_functional.bce_loss(x1.eval, x2.eval, reduction, out.eval)
     if out.is_dynamic:
         out.add_in_bounds(x1, x2)
         x1.add_out_bounds(out)
@@ -967,7 +967,7 @@ def nll_loss(x1: Tensor, x2: Tensor, reduction: str = 'mean', out: Tensor = None
         else:
             raise TypeError('unknown type for reduction')
     x2.long_()
-    nn.td_functional.nll_loss(x1.eval, x2.eval, reduction, out.eval)
+    xs.nn.td_functional.nll_loss(x1.eval, x2.eval, reduction, out.eval)
     if out.is_dynamic:
         out.add_in_bounds(x1, x2)
         x1.add_out_bounds(out)
@@ -996,7 +996,7 @@ def cross_entropy(x1: Tensor, x2: Tensor, reduction: str = 'mean', out: Tensor =
         x1.cache['softmax'] = None
     softmaxed_x1 = softmax(x1, x1.cache['softmax'])
     log_softmaxed_x1_data = GLOBAL.np.log(softmaxed_x1.eval)
-    nn.td_functional.nll_loss(log_softmaxed_x1_data, x2.eval, reduction, out.eval)
+    xs.nn.td_functional.nll_loss(log_softmaxed_x1_data, x2.eval, reduction, out.eval)
     if out.is_dynamic:
         out.add_in_bounds(x1, x2)
         x1.add_out_bounds(out)
