@@ -3,7 +3,7 @@ from .sgd import SGD, Momentum
 from .adagrad import AdaGrad
 from .adadelta import AdaDelta
 from .rmsprop import RMSprop
-from optim.optimizer import Optimizer
+from xs.optim.optimizer import Optimizer
 import copy
 
 
