@@ -1,4 +1,4 @@
-from optim.optimizer import *
+from xs.optim.optimizer import *
 
 
 class AdaDelta(Optimizer):
@@ -11,16 +11,16 @@ class AdaDelta(Optimizer):
 
     def step(self):
         if self.ms is None:
-            self.ms = [np.zeros_like(g.grad.eval) for g in self._parameters]
+            self.ms = [GLOBAL.np.zeros_like(g.grad.eval) for g in self._parameters]
         if self.delta_x is None:
-            self.delta_x = [np.zeros_like(g.grad.eval) for g in self._parameters]
+            self.delta_x = [GLOBAL.np.zeros_like(g.grad.eval) for g in self._parameters]
 
         for i, (s, var, x) in enumerate(zip(self.ms, self._parameters, self.delta_x)):
             if var.requires_grad:
-                s = self.rho * s + (1 - self.rho) * np.power(var.grad.eval, 2)
-                g_ = np.sqrt((x + self.epsilon) / (s + self.epsilon)) * var.grad.eval
+                s = self.rho * s + (1 - self.rho) * GLOBAL.np.power(var.grad.eval, 2)
+                g_ = GLOBAL.np.sqrt((x + self.epsilon) / (s + self.epsilon)) * var.grad.eval
                 var.eval -= g_
-                x = self.rho * x + (1 - self.rho) * np.power(g_, 2)
+                x = self.rho * x + (1 - self.rho) * GLOBAL.np.power(g_, 2)
                 self.ms[i] = s
                 self.delta_x[i] = x
         super(AdaDelta,self).step()
