@@ -1,5 +1,5 @@
-from utils.common import copy
-from nn.initializers import Zeros
+from xs.utils.common import copy, GLOBAL
+from xs.nn.initializers import Zeros
 
 
 class Optimizer:
