@@ -1,4 +1,4 @@
-from optim.optimizer import *
+from xs.optim.optimizer import *
 
 
 class RMSprop(Optimizer):
@@ -11,12 +11,12 @@ class RMSprop(Optimizer):
     def step(self):
         if self.ms is None:
             # initialize
-            self.ms = [np.zeros_like(p.eval) for p in self._parameters]
+            self.ms = [GLOBAL.np.zeros_like(p.eval) for p in self._parameters]
 
         for i, (s, var) in enumerate(zip(self.ms, self._parameters)):
             if var.requires_grad:
-                new_s = self.rho * s + (1 - self.rho) * np.square(var.grad.eval)
-                var.eval -= self.lr * var.grad.eval / np.sqrt(new_s + self.epsilon)
+                new_s = self.rho * s + (1 - self.rho) * GLOBAL.np.square(var.grad.eval)
+                var.eval -= self.lr * var.grad.eval / GLOBAL.np.sqrt(new_s + self.epsilon)
                 self.ms[i] = new_s
 
         super(RMSprop, self).step()
\ No newline at end of file
