@@ -1,4 +1,4 @@
-from optim.optimizer import *
+from xs.optim.optimizer import *
 
 
 class SGD(Optimizer):
@@ -18,7 +18,7 @@ class Momentum(Optimizer):
     def step(self):
         if self.velocity is None:
             # initialize
-            self.velocity = [np.zeros_like(p.eval) for p in self._parameters]
+            self.velocity = [GLOBAL.np.zeros_like(p.eval) for p in self._parameters]
 
         for i, (v, var) in enumerate(zip(self.velocity, self._parameters)):
             if var.requires_grad:
